/**
 * 
 */
package org.gcube.portlets.user.td.widgetcommonevent.client.type;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public enum WidgetRequestType {
	CHANGECOLUMNTYPEPANEL,
	ADDCOLUMNPANEL,
	DELETECOLUMNPANEL,
	SPLITCOLUMNPANEL,
	MERGECOLUMNPANEL,
	GROUPBYPANEL,
	TIMEAGGREGATIONPANEL,
	NORMALIZEPANEL,
	DENORMALIZEPANEL,
	LABELCOLUNPANEL,
	CHANGETABLETYPEPANEL,
	DUPLICATESROWSPANEL,
	VALIDATIONSTASKSPANEL,
	CURATIONBYREPLACEBATCHDIALOG,
	MONITORBACKGROUNDPANEL,
	RESOURCESPANEL;
	
}
